<?php

namespace forge12\woocommerce\free\accessories {
    require_once('ReplacePlaceholder.class.php');
    require_once('OptionalAccessories.class.php');
    require_once('Messages.class.php');
    require_once('OptionalAccessoriesToCategory.class.php');
    require_once('OptionalAccessoriesToWooCommerce.class.php');
    require_once('UI.class.php');
    require_once('UIDashboard.class.php');
    require_once('UIAccessoriesCart.class.php');
    require_once('UIOptionalAccessories.class.php');
    require_once('UIProVersion.class.php');
    require_oncE('Shortcode.class.php');

    require_once('AccessoriesCart.class.php');

    if ( ! defined( 'ABSPATH' ) ) {
        exit;
    }

    /**
     * Plugin Name: Accessories for WooCommerce
     * Plugin URI: https://www.forge12.com/produkt/woocommerce-zubehoer/
     * Description: Add accessories for WooCommerce products and categories
     * Version: 1.39
     * Author: Forge12 Interactive GmbH
     * Author URI: https://www.forge12.com
     */
    define('FORGE12_accessories_VERSION', '1.39');
    define('FORGE12_accessories_SLUG', 'f12-wc-accessories');
    define('FORGE12_accessories_BASENAME', plugin_basename(__FILE__));

    /**
     * Class Wooaccessories
     * Controller for the Acccessoires.
     *
     * @package forge12\woocommerce
     */
    class accessories
    {
        /**
         * List of all active plugins
         * @var array
         */
        private $plugins = array();

        /**
         * Wooaccessories constructor.
         */
        public function __construct()
        {
            add_action('init', array($this, 'initLanguage'));

            $UI = UI::getInstance(FORGE12_accessories_SLUG, 'Forge12 Accessories', 'manage_options');

            $UIDashboard = new UIDashboard($UI, 'f12-woo-accessories');
            $UIOptionalAccessories = new UIOptionalAccessories($UI, 'f12-woo-accessories');
            $UIAccessoriesCart = new UIAccessoriesCart($UI, 'f12-woo-accessories');
            $UIPro = new UIProVersion($UI, 'f12-woo-accessories');

            OptionalAccessories::getInstance();
            OptionalAccessoriesToCategory::getInstance();
            OptionalAccessoriesToWooCommerce::getInstance();

            AccessoriesCart::getInstance();

            add_action('admin_notices', array($this,'validateDependencies'));
        }

        /**
         * Initialize the Language files
         */
        public function initLanguage(){
            load_plugin_textdomain( 'f12-woo-accessories', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
        }

        /**
         * Add notice if woocommerce is not enabled.
         */
        public function validateDependencies(){
            if(!$this->isWooCommerceEnabled()){
                $this->showDependenciesMissing();
            }
        }

        /**
         * Check if is a plugin activated.
         * @param $plugin
         * @return bool
         */
        public function is_plugin_activated($plugin)
        {
            if(empty($this->plugins)) {
                $this->plugins = (array)get_option('active_plugins', array());
            }

            if (strpos($plugin, '.php') === false) {
                $plugin = trailingslashit($plugin) . $plugin . '.php';
            }

            return in_array($plugin, $this->plugins) || array_key_exists($plugin, $this->plugins);
        }

        /**
         * Check if woocommercei s enabled
         * @return bool
         */
        private function isWooCommerceEnabled()
        {
            return $this->is_plugin_activated('woocommerce/woocommerce.php');
        }

        /**
         * Show dependencies missing text
         */
        private function showDependenciesMissing()
        {
            include_once('woo-notice-dependencies.php');
        }

        /**
         * Return the Accessoire IDs for the given Product
         * @param int $post_id
         * @param string $type | either: required, optional or all
         *
         * @return array
         */
        public static function getAccessoireIDsByProductID($product_id, $type = 'optional')
        {
            $product = wc_get_product($product_id);

            if (null == $product || !$product) {
                return array();
            }

            if ($type == 'required') {
                $accessoire_ids = $product->get_meta('f12-woo-required_accessoire_ids');
            } else if ($type == 'all') {
                $required = $product->get_meta('f12-woo-required_accessoire_ids');
                $optional = $product->get_meta('f12-woo-accessoire_ids');

                if (empty($required)) {
                    $required = "";
                }
                if (empty($optional)) {
                    $optional = "";
                }
                $accessoire_ids = $required . ',' . $optional;
            } else {
                $accessoire_ids = $product->get_meta('f12-woo-accessoire_ids');
            }

            return explode(",", $accessoire_ids);
        }

        /**
         * Return the Accessoire IDs for the given Product and Categories
         * @param int $product_id
         * @param string $type | either: required, optional or all
         *
         * @return array
         */
        public static function getAccessoireIDs($product_id, $type = 'optional')
        {
            $product = wc_get_product($product_id);

            if (null == $product || !$product) {
                return array();
            }

            $arr_category_ids = $product->get_category_ids();

            $arr_accessoire_ids = array();

            // Get all categories
            foreach($arr_category_ids as $key => $term_id){
                $arr_group_ids = self::getAccessoireIDsByTermID($term_id, $type);
                $arr_accessoire_ids = array_merge($arr_accessoire_ids, $arr_group_ids);
            }

            $arr_product_ids = self::getAccessoireIDsByProductID($product_id, $type);
            $arr_accessoire_ids = array_merge($arr_accessoire_ids, $arr_product_ids);

            return array_filter(array_unique($arr_accessoire_ids));
        }

        /**
         * Return the Accessoire IDs for the given Product
         * @param int $post_id
         * @param string $type | either: required, optional or all
         *
         * @return array
         */
        public static function getAccessoireIDsByTermID($term_id, $type = 'optional')
        {
            if ($type == 'required') {
                $accessoire_ids = get_term_meta($term_id, 'f12-woo-required_accessoire_ids', true);
            } else if ($type == 'all') {
                $required = get_term_meta($term_id, 'f12-woo-required_accessoire_ids', true);
                $optional = get_term_meta($term_id, 'f12-woo-accessoire_ids', true);

                if (empty($required)) {
                    $required = "";
                }
                if (empty($optional)) {
                    $optional = "";
                }
                $accessoire_ids = $required . ',' . $optional;
            } else {
                $accessoire_ids = get_term_meta($term_id, 'f12-woo-accessoire_ids', true);
            }

            return explode(",", $accessoire_ids);
        }
    }

    new accessories();
}