<?php

namespace forge12\woocommerce\free\accessories {
    if (!defined('ABSPATH')) {
        exit;
    }

    /**
     * Class AccessoriesCart
     * Show Accessories below the Cart.
     *
     * @package forge12\woocommerce\accessories
     */
    class AccessoriesCart
    {
        private static $instance = null;


        public static function getInstance()
        {
            if (self::$instance == null) {
                self::$instance = new self;
            }
            return self::$instance;
        }

        /**
         * Admin constructor.
         */
        public function __construct()
        {
            $Settings = UIAccessoriesCart::getSettings();

            // Check if the settings are enabled
            if ($Settings['enable'] == 1) {
                add_action('woocommerce_after_cart', array($this, 'render'), 10);


                add_filter('f12_woo_accessories_cart_heading', array($this, 'addSettingsTitle'), 10, 1);
                add_filter('f12_woo_accessories_cart_description', array($this, 'addSettingsDescription'), 10, 1);
            }
        }

        /**
         * Update the description with the settings
         */
        public function addSettingsDescription($content)
        {
            $settings = UIAccessoriesCart::getSettings();
            if (!empty($settings['description'])) {
                $content = $settings['description'];
            }

            return $content;
        }

        /**
         * Update the title with the settings
         * @param string $content
         * @param \WC_Product $product
         * @return mixed
         */
        public function addSettingsTitle($content)
        {
            $settings = UIAccessoriesCart::getSettings();
            if (!empty($settings['title'])) {
                $content = $settings['title'];
            }

            return $content;
        }

        /**
         * Return the accessories as string
         *
         * @param int The id of the post
         *
         * @return string
         */
        public static function getContent()
        {
            $items = WC()->cart->get_cart();

            $accessory_ids_already_added = array();
            $accessory_ids = array();
            $list_of_products = array();

            /**
             * Loop trough cart items and check if they already has been added or not.
             */
            foreach ($items as $cart_item) {
                if (isset($cart_item['_accessoire_parent_key'])) {
                    $accessory_ids_already_added[] = $cart_item['product_id'];
                } else {
                    $list_of_products[] = $cart_item;
                }
            }

            /**
             * Get all Accessories for the products
             */
            $accessory_ids = array();

            foreach ($list_of_products as $cart_item) {
                // Get optional and required ids
                $accessory_ids = array_merge($accessory_ids, apply_filters('f12_woo_accessories_cart', $accessory_ids, $cart_item['product_id'], $accessory_ids_already_added));
            }

            $accessory_ids = array_unique($accessory_ids);

            if (empty($accessory_ids)) {
                return '';
            }

            $template = locate_template(
                array(
                    "woo-accessories-cart.php",
                    "f12-woo-accesoires/woo-accessories-cart.php"
                )
            );

            if (!$template) {
                $template = 'woo-accessories-cart.php';
            }
            ob_start();
            include($template);
            $content = ob_get_contents();
            ob_end_clean();

            wp_reset_postdata();

            return $content;
        }

        public function render()
        {
            if (is_cart()) {
                echo self::getContent();
            }
        }
    }
}