<?php

namespace forge12\woocommerce\free\accessories {
    if (!defined('ABSPATH')) {
        exit;
    }

    require_once('Shortcode.class.php');

    /**
     * Class Optionalaccessories
     * Responsible to handle the frontend of the accessories
     *
     * @package forge12\woocommerce\free\accessories
     */
    class OptionalAccessories
    {
        private static $instance = null;

        /**
         * List of Shortcodes
         */
        private $listShortcodes = array();

        public static function getInstance()
        {
            if (self::$instance == null) {
                self::$instance = new self;
            }
            return self::$instance;
        }

        /**
         * Admin constructor.
         */
        public function __construct()
        {
            $this->listShortcodes[] = new Shortcode();
            $Settings = UIOptionalAccessories::getSettings();

            add_action('wp_enqueue_scripts', array($this, 'addStyles'));

            // Check if the settings are enabled
            if ($Settings['enable'] == 1) {
                add_action('init', array($this, 'init'));
                add_action('woocommerce_after_single_product_summary', array($this, 'render'), $Settings['priority']);
                add_filter('f12_woo_accessories_products_heading', array($this, 'addSettingsTitle'), 10, 2);
                add_filter('f12_woo_accessories_products_description', array($this, 'addSettingsDescription'), 10, 2);

                // add filter
                add_filter('f12_woo_accessories_cart', array($this, 'getAccessoriesByProductID'), 12, 3);
            }
        }

        /**
         * Get all required accessories for the given product id
         * @param array $ids
         * @param int $product_id
         * @return array
         */
        public function getAccessoriesByProductID($ids, $product_id, $excluded = array())
        {
            $accessory_ids = accessories::getAccessoireIDs($product_id, 'optional');
            $accessory_ids = array_merge($ids, $accessory_ids);
            return array_diff($accessory_ids, $excluded);
        }

        /**
         * Update the description with the settings
         */
        public function addSettingsDescription($content, $product)
        {
            $description = $product->get_meta('f12-woo-accessoire_description', true);

            if (!$description || empty($description)) {
                $settings = UIOptionalAccessories::getSettings();
                if (!empty($settings['description'])) {
                    $content = $settings['description'];
                }
            } else {
                $content = $description;
            }

            return ReplacePlaceholder::replace($content, $product);
        }

        /**
         * Update the title with the settings
         * @param string $content
         * @param \WC_Product $product
         * @return mixed
         */
        public function addSettingsTitle($content, $product)
        {
            $title = $product->get_meta('f12-woo-accessoire_title', true);

            if (!$title || empty($title)) {
                $settings = UIOptionalAccessories::getSettings();
                if (!empty($settings['title'])) {
                    $content = $settings['title'];
                }
            } else {
                $content = $title;
            }

            return ReplacePlaceholder::replace($content, $product);
        }

        /**
         * Add Stylesheets
         */
        public function addStyles()
        {
            wp_enqueue_style('f12-woo-accessories-frontend', plugin_dir_url(__FILE__) . 'style.css');
        }

        /**
         * Init the Frontend System
         */
        public function init()
        {
            $this->listShortcodes[] = new Shortcode();
        }

        /**
         * Return the accessories as string
         *
         * @param int The id of the post
         *
         * @return string
         */
        public static function getContent($postID)
        {
            $product = wc_get_product($postID);

            $accessoire_ids = accessories::getAccessoireIDs($product->get_id());

            if (empty($accessoire_ids)) {
                return '';
            }

            $template = locate_template(
                array(
                    "woo-accessories.php",
                    "f12-woo-accesoires/woo-accessories.php"
                )
            );

            if (!$template) {
                $template = 'woo-accessories.php';
            }

            ob_start();
            include($template);
            $content = ob_get_contents();
            ob_end_clean();

            wp_reset_postdata();

            return $content;
        }

        public function render()
        {
            global $post;

            if (!$post) {
                return '';
            }

            echo Optionalaccessories::getContent($post->ID);
        }
    }
}