<?php

namespace forge12\woocommerce\free\accessories {
    if ( ! defined( 'ABSPATH' ) ) {
        exit;
    }

    require_once('Shortcode.class.php');

    /**
     * Class OptionalAccessoriesToCategory
     * Allow the option to add products for each items within a category.
     *
     * @package forge12\woocommerce\free\accessories
     */
    class OptionalAccessoriesToCategory
    {
        private static $instance = null;

        /**
         * @return OptionalAccessoriesToCategory|null
         */
        public static function getInstance()
        {
            if (self::$instance == null) {
                self::$instance = new self;
            }
            return self::$instance;
        }

        /**
         * Admin constructor.
         */
        public function __construct()
        {
            $Settings = UIOptionalAccessories::getSettings();

            // Check if the settings are enabled
            if ($Settings['enable'] == 1) {

                add_action('product_cat_add_form_fields', array($this, '_addFields'));
                add_action('create_product_cat', array($this,'_save'));

                add_action('product_cat_edit_form', array($this, '_editFields'), 99999, 2);
                add_action('edited_product_cat', array($this,'_save'));
                //add_action( 'product_cat_edit_form_fields', array( $this, 'edit_category_fields' ), 10 );
            }
        }

        /**
         * Save the optional accessories while creating or updating the prodcut category.
         */
        public function _save($term_id)
        {
            /*
             * Check if the terms have been send
             */
            if (isset($_POST['accessoire_ids']) && wp_verify_nonce($_POST['accessories_category_nonce'], 'accessories_category_action')) {
                $ids = array_map('absint', $_POST['accessoire_ids']);
                $ids = implode(",", $ids);
                update_term_meta($term_id, 'f12-woo-accessoire_ids', $ids);
            }
        }

        /**
         * Add the input fields for the optional accessories field
         * @param $tag
         */
        public function _addFields()
        {
            ?>
            <div class="box">
                <h2><?php _e('Optional Accessories', 'f12-woo-accessories'); ?></h2>
                <div class="option">
                    <select class="wc-product-search" multiple="multiple" style="width: 50%;" id="optional_accessories"
                            name="accessoire_ids[]"
                            data-placeholder="<?php esc_attr_e('Search for a product&hellip;', 'woocommerce'); ?>"
                            data-action="woocommerce_json_search_products_and_variations"
                            data-exclude="">
                    </select>
                    <?php
                    wp_nonce_field('accessories_category_action', 'accessories_category_nonce');
                    ?>
                </div>
                <p>
                    <?php _e('Pick all products which will be displayed on the product detail page within the category.', 'f12-woo-accessories'); ?>
                </p>
            </div>
            <?php
        }

        /**
         * Add the input fields for the optional accessories field
         * @param \WP_Term $tag
         */
        public function _editFields($tag, $taxonomy)
        {
            ?>
            <div class="box">
                <h2><?php _e('Optional Accessories', 'f12-woo-accessories'); ?></h2>
                <div class="option">
                    <select class="wc-product-search" multiple="multiple" style="width: 50%;" id="optional_accessories"
                            name="accessoire_ids[]"
                            data-placeholder="<?php esc_attr_e('Search for a product&hellip;', 'woocommerce'); ?>"
                            data-action="woocommerce_json_search_products_and_variations"
                            data-exclude="">

                        <?php
                        $product_ids = accessories::getAccessoireIDsByTermID($tag->term_id, 'optional');

                        foreach ($product_ids as $product_id) {
                            $product = wc_get_product($product_id);

                            if (null != $product && false != $product) {
                                echo '<option value="' . esc_attr($product_id) . '"' . selected(true, true, false) . '>' . esc_html(wp_strip_all_tags($product->get_formatted_name())) . '</option>';
                            }
                        }
                        ?>

                    </select>
                    <p>
                        <?php _e('Pick all products which will be displayed on the product detail page within the category.', 'f12-woo-accessories'); ?>
                    </p>
                    <?php
                    wp_nonce_field('accessories_category_action', 'accessories_category_nonce');
                    ?>
                </div>
            </div>
            <?php
        }
    }
}